@@ -72,8 +72,8 @@ type ClientConfig struct {
 	Password               string
 	RefreshToken           string
 	Assertion              string `validate:"omitempty,json"`
-	SigningKey             string `validate:"omitempty,uri"`
-	EncryptionKey          string `validate:"omitempty,uri"`
+	SigningKey             string `validate:"omitempty,uri|file"`
+	EncryptionKey          string `validate:"omitempty,uri|file"`
 	SubjectToken           string
 	SubjectTokenType       string `validate:"omitempty,oneof=urn:ietf:params:oauth:token-type:access_token"`
 	ActorToken             string
@@ -81,17 +81,19 @@ type ClientConfig struct {
 	IDTokenHint            string
 	LoginHint              string
 	IDPHint                string
-	TLSCert                string `validate:"omitempty,uri"`
-	TLSKey                 string `validate:"omitempty,uri"`
-	TLSRootCA              string `validate:"omitempty,uri"`
-	CallbackTLSCert        string `validate:"omitempty,uri"`
-	CallbackTLSKey         string `validate:"omitempty,uri"`
+	TLSCert                string `validate:"omitempty,uri|file"`
+	TLSKey                 string `validate:"omitempty,uri|file"`
+	TLSRootCA              string `validate:"omitempty,uri|file"`
+	CallbackTLSCert        string `validate:"omitempty,uri|file"`
+	CallbackTLSKey         string `validate:"omitempty,uri|file"`
 	HTTPTimeout            time.Duration
 	BrowserTimeout         time.Duration
 	DPoP                   bool
 	Claims                 string `validate:"omitempty,json"`
 	RAR                    string `validate:"omitempty,json"`
 	Purpose                string
+	Prompt                 []string
+	MaxAge                 string
 }
 
 func RequestAuthorization(cconfig ClientConfig, sconfig ServerConfig, hc *http.Client) (r Request, codeVerifier string, err error) {
