@@ -61,6 +61,14 @@ func (r *Request) AuthorizeRequest(
 		r.Form.Set("purpose", cconfig.Purpose)
 	}
 
+	if len(cconfig.Prompt) > 0 {
+		r.Form.Set("prompt", strings.Join(cconfig.Prompt, " "))
+	}
+
+	if len(cconfig.MaxAge) > 0 {
+		r.Form.Set("max_age", cconfig.MaxAge)
+	}
+
 	if cconfig.IDTokenHint != "" {
 		r.Form.Set("id_token_hint", cconfig.IDTokenHint)
 	}
@@ -140,6 +148,14 @@ func (r *Request) AuthorizeRequest(
 		if len(cconfig.Purpose) > 0 {
 			r.Form.Set("purpose", cconfig.Purpose)
 		}
+
+		if len(cconfig.Prompt) > 0 {
+			r.Form.Set("prompt", strings.Join(cconfig.Prompt, " "))
+		}
+
+		if len(cconfig.MaxAge) > 0 {
+			r.Form.Set("max_age", cconfig.MaxAge)
+		}
 	}
 
 	if cconfig.DPoP {
